@@ -34,7 +34,26 @@ class SyncOnly(PointError):
 
 
 class RequestError(PointError):
-    pass
+    default_status_code = status.HTTP_500_INTERNAL_SERVER_ERROR
+    default_detail = 'A server error occurred.'
+    default_url = None
+
+    def __init__(self, url=None, detail=None, status_code=None):
+        self.__url = self.default_url if url is None else url
+        self.__detail = self.default_detail if detail is None else detail
+        self.__status_code = self.default_status_code if status_code is None else status_code
+
+    def __str__(self):
+        return str(self.__detail)
+
+    def get_full_details(self):
+        if not status.is_client_error(self.__status_code):
+            raise PointError('Full details only for client errors')
+        self.__detail.update({
+            'url': self.__url,
+            'status_code': self.__status_code
+        })
+        return self.__status_code
 
 
 class ServerError(RequestError):
@@ -42,11 +61,13 @@ class ServerError(RequestError):
 
 
 class ClientError(RequestError):
-    pass
+    default_status_code = status.HTTP_400_BAD_REQUEST
+    default_detail = {'Invalid payload.'}
 
 
 class NotFound404(ClientError):
-    pass
+    default_status_code = status.HTTP_404_NOT_FOUND
+    default_detail = {'Not found'}
 
 
 class LookupFieldValueNone(PointError):
@@ -120,9 +141,9 @@ class Point:
                         self._cache = status.HTTP_404_NOT_FOUND
                         raise NotFound404(self._point_id.url)
                     else:
-                        raise ClientError(f'{response.status_code}:{self._point_id.url}:{response.json()}')
+                        raise ClientError(self._point_id.url, response.json(), response.status_code)
                 else:
-                    raise ServerError(f'{response.status_code}:{self._point_id.url}:{response.text}')
+                    raise ServerError(self._point_id.url, response.text, response.status_code)
 
 
 class ObjectPoint(Point):
