@@ -3,7 +3,7 @@ __all__ = ('OrderPoint',)
 from expressmoney.api import *
 
 
-SERVICE_NAME = 'scoring'
+SERVICE = 'scoring'
 
 
 class OrderCreateContract(Contract):
@@ -18,16 +18,13 @@ class OrderReadContract(Contract):
     order_id = serializers.IntegerField(min_value=1)
 
 
-scoring_credit_scoring_order = ID(SERVICE_NAME, 'credit_scoring', 'order')
+class OrderID(ID):
+    _service = SERVICE
+    _app = 'credit_scoring'
+    _view_set = 'order'
 
 
 class OrderPoint(ListPointMixin, CreatePointMixin, ContractPoint):
-    _point_id = scoring_credit_scoring_order
+    _point_id = OrderID()
     _read_contract = OrderReadContract
     _create_contract = OrderCreateContract
-
-
-"""
-
-
-"""
\ No newline at end of file
