@@ -3,7 +3,7 @@ __all__ = ('Scoring1CPoint',)
 from expressmoney.api import *
 
 
-SERVICE_NAME = 'scoring'
+SERVICE = 'scoring'
 
 
 class CreditScoring1CCreateContract(Contract):
@@ -31,12 +31,13 @@ class CreditScoring1CReadContract(CreditScoring1CCreateContract):
     score = serializers.DecimalField(5, 4, min_value=0, max_value=1)
 
 
-# Endpoints ID
-scoring_credit_scoring_1c_scoring_1c = ID(SERVICE_NAME, 'credit_scoring_1c', 'scoring_1c')
+class Scoring1CID(ID):
+    _service = SERVICE
+    _app = 'credit_scoring_1c'
+    _view_set = 'scoring_1c'
 
 
-# Endpoints handlers
 class Scoring1CPoint(ListPointMixin, CreatePointMixin, ContractPoint):
-    _point_id = scoring_credit_scoring_1c_scoring_1c
+    _point_id = Scoring1CID()
     _create_contract = CreditScoring1CCreateContract
     _read_contract = CreditScoring1CReadContract
